@@ -5,10 +5,11 @@ use List::MoreUtils qw/uniq/;
 use CPAN::Packager::DependencyAnalyzer;
 use CPAN::Packager::BuilderFactory;
 use CPAN::Packager::DependencyConfigMerger;
-use CPAN::Packager::ConfigLoader;
+use CPAN::Packager::Config::Loader;
+use CPAN::Packager::Util;
 with 'CPAN::Packager::Role::Logger';
 
-our $VERSION = '0.052';
+our $VERSION = '0.053';
 
 BEGIN {
     if ( !defined &DEBUG ) {
@@ -44,7 +45,7 @@ has 'dependency_config_merger' => (
 has 'config_loader' => (
     is      => 'rw',
     default => sub {
-        CPAN::Packager::ConfigLoader->new;
+        CPAN::Packager::Config::Loader->new;
     }
 );
 
@@ -69,14 +70,20 @@ sub make {
     $config->{modules} = $built_modules if $built_modules;
 
     $self->log( info => "# Analyzing dependencies for $module ... ###" );
-    my $modules = $self->analyze_module_dependencies( $module, $config );
+    my ( $modules, $resolved_module_name) = $self->analyze_module_dependencies( $module, $config );
 
     $config = $self->merge_config( $modules, $config )
         if $self->conf;
 
     $self->_dump_modules( $config->{modules} );
-    my $sorted_modules = [ uniq reverse @{ $self->topological_sort( $module, $config->{modules} ) } ];
-    $self->_dump_modules( $sorted_modules );
+
+    my $sorted_modules = [
+        uniq reverse @{
+            CPAN::Packager::Util::topological_sort( $resolved_module_name,
+                $config->{modules} )
+            }
+    ];
+    $self->_dump_modules($sorted_modules);
 
     local $@;
     unless ( $self->dry_run ) {
@@ -86,33 +93,13 @@ sub make {
     }
 
     if ($@) {
-        $self->_dump_modules( $sorted_modules );
+        $self->_dump_modules($sorted_modules);
         die "### Built packages for $module faied :-( ###" . $@;
     }
     $self->log( info => "### Built packages for $module :-) ### " );
     $built_modules;
 }
 
-sub topological_sort {
-    my ( $self, $target, $modules ) = @_;
-
-    my @results;
-
-    if ( $modules->{$target} ) {
-        push @results, $modules->{$target};
-        if ( $modules->{$target}->{depends} && @{ $modules->{$target}->{depends} } ) {
-            for my $mod ( @{ $modules->{$target}->{depends} } ) {
-                my $result = $self->topological_sort( $mod, $modules );
-                push @results, @{$result};
-            }
-        }
-    } else {
-        $self->log(info => "skipped $target. no meta data found.");
-    }
-
-    return \@results;
-}
-
 sub _dump_modules {
     my ( $self, $modules ) = @_;
     if (DEBUG) {
@@ -141,23 +128,24 @@ sub build_modules {
         next
             if $builder->is_installed( $module->{module} )
                 && !$self->always_build;
-        
+
         local $@;
         my $package = $builder->build($module);
-        
-        if ( $package ) {
+
+        if ($package) {
             $module->{build_status} = 'success';
             $self->log( info => "$module->{module} created ($package)" );
         }
         else {
             $module->{build_status} = 'failed';
             $self->log( info => "$module->{module} failed" );
-            if ( $@ ) {
+            if ($@) {
                 die "failed building module: $@";
             }
         }
     }
-    my %modules = map { $_->{module} => $_ } @{$modules};
+    my %modules = map { exists $_->{module} ? { $_->{module} => $_ } : $_ => $_; }
+        @{$modules};
     return \%modules;
 }
 
@@ -165,8 +153,8 @@ sub analyze_module_dependencies {
     my ( $self, $module, $config ) = @_;
     $self->log( info => "Analyzing dependencies for $module ..." );
     my $analyzer = $self->dependency_analyzer;
-    $analyzer->analyze_dependencies( $module, $config );
-    $analyzer->modules;
+    my $resolved_module = $analyzer->analyze_dependencies( $module, $config );
+    return ( $analyzer->modules, $resolved_module);
 }
 
 no Mouse;
